import { format, addMonths, startOfMonth, endOfMonth } from 'date-fns';
import { Component, OnInit } from "@angular/core";
import { MainService } from 'src/app/services/main.service';
@Component({
  selector: "app-incident-statistics",
  templateUrl: "./incident-statistics.component.html",
  styleUrls: ["./incident-statistics.component.less"],
})
export class IncidentStatisticsComponent implements OnInit {
  constructor(
    private mainService: MainService,
  ) {}

  listOfData: any[] = []; //表格数据
  pageIndex: number = 1; //表格当前页码
  pageSize: number = 10; //表格每页展示条数
  listLength: number = 10; //表格总数据量

  ngOnInit() {
    this.initSessionData();
    this.search();
  }

  // 初始化缓存数据
  queryType:any;
  hosId:any;
  dutyId:any;
  parentDutyId:any;
  initSessionData(){
    let maintenanceStatistics = JSON.parse(sessionStorage.getItem('maintenanceStatistics'));
    let queryType:any = maintenanceStatistics.queryType;
    let hosId:any = maintenanceStatistics.hospitalId;
    let dutyId:any = maintenanceStatistics.dutyId;

    queryType = queryType ? +queryType : undefined;
    hosId = hosId ? +hosId : undefined;
    dutyId = dutyId ? +dutyId : undefined;

    this.queryType = queryType;
    if(queryType == 1){
      this.hosId = undefined;
      this.dutyId = undefined;
      this.parentDutyId = undefined;
    }else if(queryType == 2){
      this.hosId = hosId;
      this.dutyId = undefined;
      this.parentDutyId = undefined;
    }else if(queryType == 3){
      this.hosId = undefined;
      this.dutyId = dutyId;
      this.parentDutyId = undefined;
    }else if(queryType == 4){
      this.hosId = undefined;
      this.dutyId = undefined;
      this.parentDutyId = dutyId;
    }
  }

  // 表格数据
  loading1 = false;
  getList(num?: number, field?: string, sort?: string) {
    if (num !== undefined) {
      this.pageIndex = num;
    }
    let postData:any = {
      idx: this.pageIndex - 1,
      sum: this.pageSize,
      startDate: this.dateRange[0],
      endDate: this.dateRange[1],
      hosId: this.hosId,
      dutyId: this.dutyId,
      parentDutyId: this.parentDutyId,
    };
    if (field && sort) {
      postData.sort = `${field} ${sort === "ascend" ? `asc` : `desc`}`
    }
    this.loading1 = true;
    this.mainService
      .postCustom("itsm/report", "incidentWorkOrder", postData)
      .subscribe((result) => {
        this.loading1 = false;
        this.listOfData = result.dataList || [];
        this.listLength = result.totalCount;
      });
  }

  // 列表排序
  sortCurrent = {};
  sortCurrentKey: string = "";
  sortCurrentValue: string | null = "";
  sort(e) {
    const { key, value } = e;
    this.sortCurrentKey = key;
    this.sortCurrentValue = value;
    this.getList(this.pageIndex, this.sortCurrentKey, this.sortCurrentValue);
  }

  // 搜索
  search(num?: number) {
    if (num !== undefined) {
      this.getList(num, this.sortCurrentKey, this.sortCurrentValue);
    } else {
      this.getList(this.pageIndex, this.sortCurrentKey, this.sortCurrentValue);
    }
  }

  // 日期选择 日
  dateRange: any = [format(startOfMonth(addMonths(new Date(), -2)), 'yyyy-MM-dd HH:mm:ss'), format(endOfMonth(addMonths(new Date(), -1)), 'yyyy-MM-dd HH:mm:ss')]; //发起时间区间 天
  changeDate(result?): void {
    console.log(this.dateRange);
    console.log(result);
    result[0] = format(result[0], 'yyyy-MM-dd HH:mm:ss');
    result[1] = format(result[1], 'yyyy-MM-dd HH:mm:ss');
    this.dateRange = result;
    this.search();
  }

  onCalendarChangeDate(dateArr){
    console.log(dateArr)
    if(dateArr.length == 2){
      let dateStart = new Date(dateArr[0]);
      let dateEnd = new Date(dateArr[1]);
      dateStart.setHours(0,0,0);
      dateEnd.setHours(23,59,59);
      this.dateRange = [dateStart,dateEnd];
    }
  }

  excelExport(){}
  reset(){}
}
